exponentiatedOrnsteinUhlenbeck: Simulate an exponentiated OU volatility process
Description
exponentiatedOrnsteinUhlenbeck simulates an exponentiated Ornstein-Uhlenbeckprocess of the correct length to
be used as the volatility process within the hybrid scheme.
Usage
exponentiatedOrnsteinUhlenbeck(N, n, T, theta, beta)
Arguments
N
positive integer determining the number of terms in the Riemman sum element of the
hybrid scheme calculation. Should be of order at least n.
n
positive integer indicating the number of observations per unit of time. It represents the fineness or frequency of observations.
T
the time interval to simulate the BSS process over.
theta
positive number giving the mean reversion rate of the OU process.
beta
the factor in the exponential.
Value
The function returns a vector of length N + n*T + 1