Asymptotic scale factor for the gamma kernel
gammaKernelTauAsymptotic(n, alpha)a positive integer indicating the number of observations per unit of time.
the smoothness parameter, alpha, for the gamma kernel.
The function returns an approximation for the scale factor (tau_n) for the gamma kernel with
smoothness parameter alpha, observed at frequency n per unit of time, using the asymptotic
expression for the scale factor.