Learn R Programming

BSS (version 0.1.0)

hybridSchemeCovarianceMatrix: Hybrid scheme covariance matrix

Description

Generates the covariance matrix used in simulating Brownian semistationary processes by the hybrid scheme.

Usage

hybridSchemeCovarianceMatrix(kappa, n, alpha)

Arguments

kappa

number of terms needed for the lower sum in the hybrid scheme.

n

number of observations per unit of time, n = 1/delta.

alpha

smoothness parameter used in the BSS simulation.

Value

Returns the covariance matrix for the lower sum in the hybrid scheme calculations. The dimensions of the covariance matrix will be (kappa + 1) by (kappa + 1).

Examples

Run this code
# NOT RUN {
kappa <- 3
n <- 100
alpha <- -0.2

hybridSchemeCovarianceMatrix(kappa, n, alpha)


# }

Run the code above in your browser using DataLab