Generates the covariance matrix used in simulating Brownian semistationary processes by
the hybrid scheme.
Usage
hybridSchemeCovarianceMatrix(kappa, n, alpha)
Arguments
kappa
number of terms needed for the lower sum in the hybrid scheme.
n
number of observations per unit of time, n = 1/delta.
alpha
smoothness parameter used in the BSS simulation.
Value
Returns the covariance matrix for the lower sum in the hybrid scheme calculations.
The dimensions of the covariance matrix will be (kappa + 1) by (kappa + 1).